%{

/*  VT1500 Device Driver for Linux, Version 1.0.10
 *  Copyright (C) 1995-2001  M. Gutschke
 *
 *  At the time of writing my e-mail address is:
 *	Internet: markus@gutschke.com
 *  My snail mail address is:
 *	Markus Gutschke
 *	3637 Fillmore Street #106
 *	San Francisco, CA 94123-1600
 *	USA
 *  If you like this software, I would appreciate if you sent me a postcard
 *  from your hometown. Under the terms of the GNU general public license
 *  you are free to include this program into (commercial) software
 *  distributions (e.g. putting it onto CD-ROM); nonetheless, I would really
 *  appreciate if you dropped me a short note (sending me a sample copy of
 *  your distribution would be even more appreciated!)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * Lexical scanner for handling server input
 */

#include <stdlib.h>
#include <string.h>
#include "server.h"
#include "servlex.h"
#include "servyacc.tab.h"

extern int servread(void *,int);
#undef  YY_INPUT
#define YY_INPUT(b,r,m) ((r) = servread((b),(m)))

%}

%option noyywrap

%%

author			{ return(AUTHOR); }
warranty		{ return(WARRANTY); }
conditions		{ return(CONDITIONS); }
help			{ return(HELP); }
quit			{ return(QUIT); }
kill			{ return(KILL); }
warp			{ return(WARP); }
sndCmd			{ return(SNDCMD); }
setRadio		{ return(SETRADIO); }
setFrq			{ return(SETFRQ); }
setChannel		{ return(SETCHANNEL); }
setVolume		{ return(SETVOLUME); }
setBass			{ return(SETBASS); }
setTreble		{ return(SETTREBLE); }
setMute			{ return(SETMUTE); }
tmpMute			{ return(TMPMUTE); }
refreshMute		{ return(REFRESHMUTE); }
setVGA			{ return(SETVGA); }
setTV			{ return(SETTV); }
setVCR			{ return(SETVCR); }
setPAL			{ return(SETPAL); }
setNTSC			{ return(SETNTSC); }
setHue			{ return(SETHUE); }
setBrightness		{ return(SETBRIGHTNESS); }
setSaturation		{ return(SETSATURATION); }
setContrast		{ return(SETCONTRAST); }
setRed			{ return(SETRED); }
setGreen		{ return(SETGREEN); }
setBlue			{ return(SETBLUE); }
channelName		{ return(CHANNELNAME); }
isVisible		{ return(ISVISIBLE); }
isRadio			{ return(ISRADIO); }
getTVVCR		{ return(GETTVVCR); }
getPALNTSC		{ return(GETPALNTSC); }
getChannel		{ return(GETCHANNEL); }
getFrq			{ return(GETFRQ); }
getMute			{ return(GETMUTE); }
getExternalMute		{ return(GETEXTERNALMUTE); }
getBass			{ return(GETBASS); }
getTreble		{ return(GETTREBLE); }
getVolume		{ return(GETVOLUME); }
getInternalVolume	{ return(GETINTERNALVOLUME); }
getExternalVolume	{ return(GETEXTERNALVOLUME); }
getBrightness		{ return(GETBRIGHTNESS); }
getSaturation		{ return(GETSATURATION); }
getContrast		{ return(GETCONTRAST); }
getHue			{ return(GETHUE); }
getRed			{ return(GETRED); }
getGreen		{ return(GETGREEN); }
getBlue			{ return(GETBLUE); }
channelInfo		{ return(CHANNELINFO); }
setChannelInfo		{ return(SETCHANNELINFO); }
clearScreen		{ return(CLEARSCREEN); }
showHelp		{ return(SHOWHELP); }
showTVVCR		{ return(SHOWTVVCR); }
showMute		{ return(SHOWMUTE); }
showBass		{ return(SHOWBASS); }
showTreble		{ return(SHOWTREBLE); }
showVolume		{ return(SHOWVOLUME); }
showColor		{ return(SHOWCOLOR); }
showChannel		{ return(SHOWCHANNEL); }

[\003\004]		{ serverror("user break"); longjmp(breakPressed,0); }
[ \r\n\t]+		{; /* ignore whitespace */}
#.*			{; /* ignore comments   */}
0[xX][0-9a-fA-F]+	{ servlval.iParm = (int)strtoul(servtext+2,NULL,16);
                          return(NUMBER);}
[-+]?[0-9]+		{ servlval.iParm = atoi(servtext); return(NUMBER); }
[a-zA-Z][a-zA-Z0-9]*	{ servlval.sParm = strdup(servtext);
                          return(NAME); }
\"[^"\n]*["\n]		{ strrchr(servlval.sParm = strdup(servtext+1),
                                  '\000')[-1] = '\000';
                          return(STRING); }
.                       { return(*servtext); }

%%

void *serv_suppress_gcc_warning_about_yyunput = yyunput;

void serverror(const char *s)
{
  static char msg[130] = "Server error: ";

  msg[14] = '\000';
  strcat(strncat(msg,s,sizeof(msg)-2),"\n");
  writeClient(msg,strlen(msg));
  return;
}
